import pytest
import os

import numpy as np

base_files_path = os.path.join("examples", "molecule_files", "mol_files")


class BaseTestMolParser:
    acetone_2d = os.path.join(base_files_path, "acetone_2d.mol")
    acetone_3d = os.path.join(base_files_path, "acetone_3d.mol")
    morphine_2d = os.path.join(base_files_path, "morphine_2d.mol")
    morphine_3d = os.path.join(base_files_path, "morphine_3d.mol")
    heme_2d = os.path.join(base_files_path, "heme_2d.mol")
    heme_3d = os.path.join(base_files_path, "heme_3d.mol")

    @pytest.fixture
    def acetone_2d_file_data(self):
        return [
            "180\n",
            "  -OEChem-02092506182D\n",
            "\n",
            " 10  9  0     0  0  0  0  0  0999 V2000\n",
            "    3.7320    0.7500    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660    0.2500    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0000    0.7500    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660   -0.7500    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.3100    1.2869    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.4631    1.0600    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.6900    0.2131    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.2460   -0.7500    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660   -1.3700    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.4860   -0.7500    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "  1  2  2  0  0  0  0\n",
            "  2  3  1  0  0  0  0\n",
            "  2  4  1  0  0  0  0\n",
            "  3  5  1  0  0  0  0\n",
            "  3  6  1  0  0  0  0\n",
            "  3  7  1  0  0  0  0\n",
            "  4  8  1  0  0  0  0\n",
            "  4  9  1  0  0  0  0\n",
            "  4 10  1  0  0  0  0\n",
            "M  END\n",
        ]

    @pytest.fixture
    def acetone_3d_file_data(self):
        return [
            "180\n",
            "  -OEChem-02092506183D\n",
            "\n",
            " 10  9  0     0  0  0  0  0  0999 V2000\n",
            "    0.0003   -1.3171   -0.0002 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.0000   -0.0872    0.0006 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.2810    0.7024   -0.0002 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.2813    0.7019   -0.0002 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.3279    1.3235   -0.8980 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.3260    1.3282    0.8945 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.1351    0.0196    0.0027 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.1352    0.0187    0.0027 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.3284    1.3230   -0.8980 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.3266    1.3278    0.8945 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "  1  2  2  0  0  0  0\n",
            "  2  3  1  0  0  0  0\n",
            "  2  4  1  0  0  0  0\n",
            "  3  5  1  0  0  0  0\n",
            "  3  6  1  0  0  0  0\n",
            "  3  7  1  0  0  0  0\n",
            "  4  8  1  0  0  0  0\n",
            "  4  9  1  0  0  0  0\n",
            "  4 10  1  0  0  0  0\n",
            "M  END\n",
            "\n",
        ]

    @pytest.fixture
    def morphine_2d_file_data(self):
        return [
            "5288826\n",
            "  -OEChem-02092506132D\n",
            "\n",
            " 40 44  0     1  0  0  0  0  0999 V2000\n",
            "    2.2314    0.0528    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0000   -2.4021    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0000    2.4021    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.1607   -0.9511    0.0000 N   0  0  3  0  0  0  0  0  0  0  0  0\n",
            "    3.6897   -0.4755    0.0000 C   0  0  1  0  0  0  0  0  0  0  0  0\n",
            "    4.5133   -0.9511    0.0000 C   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    5.3370   -0.4755    0.0000 C   0  0  1  0  0  0  0  0  0  0  0  0\n",
            "    2.8660   -0.9511    0.0000 C   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    4.2392    0.2219    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.6897    0.4755    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.3370    0.4755    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.5918    0.2219    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.5133    0.9511    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660   -1.9022    0.0000 C   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    4.5133   -1.9022    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660    0.9511    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.6897   -2.3777    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.8418   -1.6832    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.5133    1.9022    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660    1.9022    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.6897    2.3777    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.0597   -1.6022    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.6284   -1.2740    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0496   -1.1875    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.3760    0.8266    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.6795    0.4887    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.9476    0.3679    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.5490    1.0581    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.1840    0.4057    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.4989    0.8349    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8660   -2.5222    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.0503   -2.2122    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.6897   -2.9977    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.3879   -2.1055    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.2641   -2.1371    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.2957   -1.2609    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.0503    2.2122    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.6897    2.9977    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0000   -3.0222    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0000    3.0222    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "  1  8  1  0  0  0  0\n",
            "  1 16  1  0  0  0  0\n",
            " 14  2  1  6  0  0  0\n",
            "  2 39  1  0  0  0  0\n",
            "  3 20  1  0  0  0  0\n",
            "  3 40  1  0  0  0  0\n",
            "  4  7  1  0  0  0  0\n",
            "  4 12  1  0  0  0  0\n",
            "  4 18  1  0  0  0  0\n",
            "  5  6  1  0  0  0  0\n",
            "  5  8  1  0  0  0  0\n",
            "  5  9  1  1  0  0  0\n",
            "  5 10  1  0  0  0  0\n",
            "  6  7  1  0  0  0  0\n",
            "  6 15  1  0  0  0  0\n",
            "  6 22  1  1  0  0  0\n",
            "  7 11  1  0  0  0  0\n",
            "  7 23  1  6  0  0  0\n",
            "  8 14  1  0  0  0  0\n",
            "  8 24  1  1  0  0  0\n",
            "  9 12  1  0  0  0  0\n",
            "  9 25  1  0  0  0  0\n",
            "  9 26  1  0  0  0  0\n",
            " 10 13  2  0  0  0  0\n",
            " 10 16  1  0  0  0  0\n",
            " 11 13  1  0  0  0  0\n",
            " 11 27  1  0  0  0  0\n",
            " 11 28  1  0  0  0  0\n",
            " 12 29  1  0  0  0  0\n",
            " 12 30  1  0  0  0  0\n",
            " 13 19  1  0  0  0  0\n",
            " 14 17  1  0  0  0  0\n",
            " 14 31  1  0  0  0  0\n",
            " 15 17  2  0  0  0  0\n",
            " 15 32  1  0  0  0  0\n",
            " 16 20  2  0  0  0  0\n",
            " 17 33  1  0  0  0  0\n",
            " 18 34  1  0  0  0  0\n",
            " 18 35  1  0  0  0  0\n",
            " 18 36  1  0  0  0  0\n",
            " 19 21  2  0  0  0  0\n",
            " 19 37  1  0  0  0  0\n",
            " 20 21  1  0  0  0  0\n",
            " 21 38  1  0  0  0  0\n",
            "M  END\n",
        ]

    @pytest.fixture
    def morphine_3d_file_data(self):
        return [
            "5288826\n",
            "  -OEChem-02092506133D\n",
            "\n",
            " 40 44  0     1  0  0  0  0  0999 V2000\n",
            "   -1.9930   -0.4740    1.2005 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.7826   -2.5168   -0.2218 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.6220    1.8421    0.5579 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.1777   -0.0101    0.4474 N   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    0.3699   -0.7149    0.6616 C   0  0  1  0  0  0  0  0  0  0  0  0\n",
            "    1.2913   -1.3046   -0.4170 C   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    2.3441   -0.2023   -0.7640 C   0  0  1  0  0  0  0  0  0  0  0  0\n",
            "   -0.9377   -1.4750    0.9848 C   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    1.1988   -0.3907    1.9201 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.2516    0.5302    0.1205 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.6887    1.1052   -1.3279 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.4315    0.4754    1.6126 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.3384    1.4306   -0.7480 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.3631   -2.5067   -0.0924 C   0  0  2  0  0  0  0  0  0  0  0  0\n",
            "    0.5066   -1.8183   -1.5971 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.5672    0.6306    0.5136 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.7155   -2.3492   -1.4425 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.3733    0.7916    0.2084 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.4184    2.5415   -1.1246 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.3310    1.7217    0.1620 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.7382    2.6936   -0.6541 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.8278   -2.1759   -0.0118 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.0029   -0.6035   -1.5465 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.8451   -2.0128    1.9373 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.5366   -1.3335    2.3712 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.5899    0.1174    2.6790 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.5474    0.9596   -2.4075 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.3530    1.9680   -1.2194 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.1271    1.5205    1.4760 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.0801    0.4584    2.4975 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.0772   -3.5067    0.2593 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.9601   -1.7947   -2.5831 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.2300   -2.7505   -2.3109 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.1500    1.8479    0.0287 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.9380    0.4055   -0.6472 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.0444    0.7352    1.0730 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.0062    3.2824   -1.8043 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.3121    3.5638   -0.9645 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.1557   -2.6446    0.6672 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.8483    1.0686    1.1031 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "  1  8  1  0  0  0  0\n",
            "  1 16  1  0  0  0  0\n",
            "  2 14  1  0  0  0  0\n",
            "  2 39  1  0  0  0  0\n",
            "  3 20  1  0  0  0  0\n",
            "  3 40  1  0  0  0  0\n",
            "  4  7  1  0  0  0  0\n",
            "  4 12  1  0  0  0  0\n",
            "  4 18  1  0  0  0  0\n",
            "  5  6  1  0  0  0  0\n",
            "  5  8  1  0  0  0  0\n",
            "  5  9  1  0  0  0  0\n",
            "  5 10  1  0  0  0  0\n",
            "  6  7  1  0  0  0  0\n",
            "  6 15  1  0  0  0  0\n",
            "  6 22  1  0  0  0  0\n",
            "  7 11  1  0  0  0  0\n",
            "  7 23  1  0  0  0  0\n",
            "  8 14  1  0  0  0  0\n",
            "  8 24  1  0  0  0  0\n",
            "  9 12  1  0  0  0  0\n",
            "  9 25  1  0  0  0  0\n",
            "  9 26  1  0  0  0  0\n",
            " 10 13  2  0  0  0  0\n",
            " 10 16  1  0  0  0  0\n",
            " 11 13  1  0  0  0  0\n",
            " 11 27  1  0  0  0  0\n",
            " 11 28  1  0  0  0  0\n",
            " 12 29  1  0  0  0  0\n",
            " 12 30  1  0  0  0  0\n",
            " 13 19  1  0  0  0  0\n",
            " 14 17  1  0  0  0  0\n",
            " 14 31  1  0  0  0  0\n",
            " 15 17  2  0  0  0  0\n",
            " 15 32  1  0  0  0  0\n",
            " 16 20  2  0  0  0  0\n",
            " 17 33  1  0  0  0  0\n",
            " 18 34  1  0  0  0  0\n",
            " 18 35  1  0  0  0  0\n",
            " 18 36  1  0  0  0  0\n",
            " 19 21  2  0  0  0  0\n",
            " 19 37  1  0  0  0  0\n",
            " 20 21  1  0  0  0  0\n",
            " 21 38  1  0  0  0  0\n",
            "M  END\n",
        ]

    @pytest.fixture
    def heme_2d_file_data(self):
        return [
            "26945\n",
            "  -OEChem-02092506282D\n",
            "\n",
            " 75 78  0     0  0  0  0  0  0999 V2000\n",
            "    6.7437    0.7222    0.0000 Fe  0  2  0  0  0  0  0  0  0  0  0  0\n",
            "    7.6407   -5.2892    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   13.2337    0.2017    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    9.0357   -4.2626    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   12.1910   -1.1813    0.0000 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.7568   -0.2777    0.0000 N   0  5  0  0  0  0  0  0  0  0  0  0\n",
            "    8.2586    1.0918    0.0000 N   0  5  0  0  0  0  0  0  0  0  0  0\n",
            "    5.2534    1.0918    0.0000 N   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.7233    2.4613    0.0000 N   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.2574   -1.8464    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    9.7955    0.6247    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.5588   -0.8787    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.8596    0.3568    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.2562   -1.8464    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    9.7955    1.6259    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.8502   -2.6518    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   10.5940    0.0227    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.9549   -0.9122    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.8261    1.8938    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.5599   -0.6109    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.9872   -0.6109    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.5265    2.8280    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.4491   -3.5678    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   11.5146    0.4132    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.6858    0.3233    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.5588    3.1293    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.5855   -2.5881    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   10.5912    2.2315    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.7182    0.5912    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.2239    4.0635    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.9214    3.0958    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.2228    4.0635    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.6858    1.8603    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.7182    1.5924    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.9537    2.8280    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.8521    0.0912    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.6300    4.8689    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.0418   -4.3732    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   12.3131   -0.1888    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.7995    4.8812    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.9223    2.1979    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.3791    5.7886    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0000    1.8114    0.0000 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.3663   -2.9953    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.2781   -2.2032    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   10.1405   -0.4000    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   10.9316   -0.4974    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.9897   -1.0577    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.5510   -1.0515    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.9630    3.2682    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.9329   -3.2243    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.0211   -4.0165    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   11.9681    0.8359    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   11.1770    0.9333    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.1257   -2.1723    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.1697   -3.0480    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.0454   -3.0040    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   10.9667    1.7382    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   11.0846    2.6070    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   10.2157    2.7249    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.5153    3.2664    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.5421    0.6281    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.3152   -0.2188    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.1622   -0.4457    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.1293    5.2364    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.2625    5.3682    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.1307    4.5014    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.4170    4.8257    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.0007    2.8129    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    7.7360    6.2956    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.7616    5.8441    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.5066    2.1868    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.9216    1.1963    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.0082   -5.7886    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   13.7288   -0.1715    0.0000 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "  2 38  1  0  0  0  0\n",
            "  2 74  1  0  0  0  0\n",
            "  3 39  1  0  0  0  0\n",
            "  3 75  1  0  0  0  0\n",
            "  4 38  2  0  0  0  0\n",
            "  5 39  2  0  0  0  0\n",
            "  6 12  1  0  0  0  0\n",
            "  6 18  1  0  0  0  0\n",
            "  7 13  1  0  0  0  0\n",
            "  7 19  1  0  0  0  0\n",
            "  8 25  2  0  0  0  0\n",
            "  8 33  1  0  0  0  0\n",
            "  9 26  1  0  0  0  0\n",
            "  9 31  2  0  0  0  0\n",
            " 10 12  1  0  0  0  0\n",
            " 10 14  2  0  0  0  0\n",
            " 10 16  1  0  0  0  0\n",
            " 11 13  2  0  0  0  0\n",
            " 11 15  1  0  0  0  0\n",
            " 11 17  1  0  0  0  0\n",
            " 12 20  2  0  0  0  0\n",
            " 13 20  1  0  0  0  0\n",
            " 14 18  1  0  0  0  0\n",
            " 14 27  1  0  0  0  0\n",
            " 15 19  2  0  0  0  0\n",
            " 15 28  1  0  0  0  0\n",
            " 16 23  1  0  0  0  0\n",
            " 16 44  1  0  0  0  0\n",
            " 16 45  1  0  0  0  0\n",
            " 17 24  1  0  0  0  0\n",
            " 17 46  1  0  0  0  0\n",
            " 17 47  1  0  0  0  0\n",
            " 18 21  2  0  0  0  0\n",
            " 19 22  1  0  0  0  0\n",
            " 20 48  1  0  0  0  0\n",
            " 21 25  1  0  0  0  0\n",
            " 21 49  1  0  0  0  0\n",
            " 22 26  2  0  0  0  0\n",
            " 22 50  1  0  0  0  0\n",
            " 23 38  1  0  0  0  0\n",
            " 23 51  1  0  0  0  0\n",
            " 23 52  1  0  0  0  0\n",
            " 24 39  1  0  0  0  0\n",
            " 24 53  1  0  0  0  0\n",
            " 24 54  1  0  0  0  0\n",
            " 25 29  1  0  0  0  0\n",
            " 26 30  1  0  0  0  0\n",
            " 27 55  1  0  0  0  0\n",
            " 27 56  1  0  0  0  0\n",
            " 27 57  1  0  0  0  0\n",
            " 28 58  1  0  0  0  0\n",
            " 28 59  1  0  0  0  0\n",
            " 28 60  1  0  0  0  0\n",
            " 29 34  2  0  0  0  0\n",
            " 29 36  1  0  0  0  0\n",
            " 30 32  2  0  0  0  0\n",
            " 30 40  1  0  0  0  0\n",
            " 31 32  1  0  0  0  0\n",
            " 31 35  1  0  0  0  0\n",
            " 32 37  1  0  0  0  0\n",
            " 33 34  1  0  0  0  0\n",
            " 33 35  2  0  0  0  0\n",
            " 34 41  1  0  0  0  0\n",
            " 35 61  1  0  0  0  0\n",
            " 36 62  1  0  0  0  0\n",
            " 36 63  1  0  0  0  0\n",
            " 36 64  1  0  0  0  0\n",
            " 37 65  1  0  0  0  0\n",
            " 37 66  1  0  0  0  0\n",
            " 37 67  1  0  0  0  0\n",
            " 40 42  2  0  0  0  0\n",
            " 40 68  1  0  0  0  0\n",
            " 41 43  2  0  0  0  0\n",
            " 41 69  1  0  0  0  0\n",
            " 42 70  1  0  0  0  0\n",
            " 42 71  1  0  0  0  0\n",
            " 43 72  1  0  0  0  0\n",
            " 43 73  1  0  0  0  0\n",
            "M  CHG  3   1   2   6  -1   7  -1\n",
            "M  END\n",
        ]

    @pytest.fixture
    def heme_3d_file_data(self):
        return [
            "4971\n",
            "  -OEChem-02092506283D\n",
            "\n",
            " 76 80  0     0  0  0  0  0  0999 V2000\n",
            "    7.1385    2.7050   -0.6711 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.7615   -3.2503   -2.9408 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.7154    2.1599    1.4930 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.1372   -3.4886   -0.7132 O   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.5250    1.9272    0.2862 N   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.6939   -1.1180    0.2758 N   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.4051    1.5170    0.2379 N   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.1811   -1.3404    0.4974 N   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.5070    2.3377    0.8711 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0591   -2.6167    0.1996 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.6482    1.2058    0.4657 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.6304    3.3517    0.8618 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.5429   -1.2639    0.3342 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.0549   -3.5020    0.2769 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.3143    2.8720    0.4652 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.1068   -2.6087    0.4631 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.0505    3.1577   -0.1110 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.9963   -0.6924    0.2747 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.5688   -2.4592    0.5400 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.7828    1.7074   -0.2302 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.9475    2.2748    1.2062 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.5095   -2.9072    0.0057 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.2658   -0.1348    0.3202 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.0486    3.7530   -0.8571 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.7892   -1.9053    0.5602 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.1304    2.8451   -0.9341 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.9471   -2.9601    0.7181 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.7823    3.6329    0.3107 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.4551   -3.2035    0.6248 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.5176    0.5263    0.0526 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.9005    4.7807    1.1965 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.8520    2.5394    0.0033 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.9112   -2.9257   -1.4638 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.0259   -4.9791    0.1919 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.9926    5.1012   -1.4661 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -6.2814   -1.8735    0.6439 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -5.3600    3.0491   -1.6044 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.3596   -4.3097    1.0073 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.3128    2.4348    0.3698 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    5.3729   -3.2588   -1.6419 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -6.1715    2.1311   -2.1847 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.6339   -5.2115    0.0645 C   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.1938    1.3129    1.6711 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.1687    3.0159    1.9856 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.7406   -3.8863    0.4471 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.1341   -2.2066    0.5729 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.3403   -0.1671    0.1855 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -0.7083    4.7057    0.4708 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.5138   -4.2667    0.8304 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -2.0287    1.2921    0.8961 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.9035   -0.5315    0.0596 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -5.5979    0.6383    0.0920 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.2897    5.1008    2.0471 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.9482    4.9486    1.4639 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    1.6775    5.4274    0.3414 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.6712    3.5474   -0.3875 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    4.6518    1.8113   -0.7907 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.3272   -3.6772   -2.0076 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    3.7327   -1.9441   -1.9173 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    2.0137   -5.3942   -0.0290 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.3499   -5.3061   -0.6044 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    0.6873   -5.4128    1.1379 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.5447    5.8188   -0.8503 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -3.4318    5.0997   -2.4692 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -1.9644    5.4627   -1.5680 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -6.7151   -1.5506   -0.3082 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -6.6100   -1.1876    1.4317 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -6.7014   -2.8571    0.8758 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -5.6930    4.0826   -1.6921 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.4411   -4.5822    2.0553 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -7.0854    2.4544   -2.6733 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -5.9398    1.0737   -2.2183 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.9394   -6.2155    0.3391 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "   -4.5621   -4.9765   -0.9923 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    8.0834    2.6451   -0.4143 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "    6.7157   -3.4560   -3.0389 H   0  0  0  0  0  0  0  0  0  0  0  0\n",
            "  1 39  1  0  0  0  0\n",
            "  1 75  1  0  0  0  0\n",
            "  2 40  1  0  0  0  0\n",
            "  2 76  1  0  0  0  0\n",
            "  3 39  2  0  0  0  0\n",
            "  4 40  2  0  0  0  0\n",
            "  5 17  1  0  0  0  0\n",
            "  5 20  1  0  0  0  0\n",
            "  5 50  1  0  0  0  0\n",
            "  6 18  1  0  0  0  0\n",
            "  6 19  1  0  0  0  0\n",
            "  6 51  1  0  0  0  0\n",
            "  7 11  2  0  0  0  0\n",
            "  7 15  1  0  0  0  0\n",
            "  8 13  1  0  0  0  0\n",
            "  8 16  2  0  0  0  0\n",
            "  9 11  1  0  0  0  0\n",
            "  9 12  2  0  0  0  0\n",
            "  9 21  1  0  0  0  0\n",
            " 10 13  1  0  0  0  0\n",
            " 10 14  2  0  0  0  0\n",
            " 10 22  1  0  0  0  0\n",
            " 11 23  1  0  0  0  0\n",
            " 12 15  1  0  0  0  0\n",
            " 12 31  1  0  0  0  0\n",
            " 13 23  2  0  0  0  0\n",
            " 14 16  1  0  0  0  0\n",
            " 14 34  1  0  0  0  0\n",
            " 15 28  2  0  0  0  0\n",
            " 16 29  1  0  0  0  0\n",
            " 17 24  2  0  0  0  0\n",
            " 17 28  1  0  0  0  0\n",
            " 18 25  1  0  0  0  0\n",
            " 18 30  2  0  0  0  0\n",
            " 19 27  1  0  0  0  0\n",
            " 19 29  2  0  0  0  0\n",
            " 20 26  2  0  0  0  0\n",
            " 20 30  1  0  0  0  0\n",
            " 21 32  1  0  0  0  0\n",
            " 21 43  1  0  0  0  0\n",
            " 21 44  1  0  0  0  0\n",
            " 22 33  1  0  0  0  0\n",
            " 22 45  1  0  0  0  0\n",
            " 22 46  1  0  0  0  0\n",
            " 23 47  1  0  0  0  0\n",
            " 24 26  1  0  0  0  0\n",
            " 24 35  1  0  0  0  0\n",
            " 25 27  2  0  0  0  0\n",
            " 25 36  1  0  0  0  0\n",
            " 26 37  1  0  0  0  0\n",
            " 27 38  1  0  0  0  0\n",
            " 28 48  1  0  0  0  0\n",
            " 29 49  1  0  0  0  0\n",
            " 30 52  1  0  0  0  0\n",
            " 31 53  1  0  0  0  0\n",
            " 31 54  1  0  0  0  0\n",
            " 31 55  1  0  0  0  0\n",
            " 32 39  1  0  0  0  0\n",
            " 32 56  1  0  0  0  0\n",
            " 32 57  1  0  0  0  0\n",
            " 33 40  1  0  0  0  0\n",
            " 33 58  1  0  0  0  0\n",
            " 33 59  1  0  0  0  0\n",
            " 34 60  1  0  0  0  0\n",
            " 34 61  1  0  0  0  0\n",
            " 34 62  1  0  0  0  0\n",
            " 35 63  1  0  0  0  0\n",
            " 35 64  1  0  0  0  0\n",
            " 35 65  1  0  0  0  0\n",
            " 36 66  1  0  0  0  0\n",
            " 36 67  1  0  0  0  0\n",
            " 36 68  1  0  0  0  0\n",
            " 37 41  2  0  0  0  0\n",
            " 37 69  1  0  0  0  0\n",
            " 38 42  2  0  0  0  0\n",
            " 38 70  1  0  0  0  0\n",
            " 41 71  1  0  0  0  0\n",
            " 41 72  1  0  0  0  0\n",
            " 42 73  1  0  0  0  0\n",
            " 42 74  1  0  0  0  0\n",
            "M  END\n",
        ]

    @pytest.fixture
    def acetone_2d_molecule_data(self):
        return (
            {
                1: {
                    "coords": np.array([3.732, 0.75, 0.0]),
                    "element": "O",
                    "bond_to": {2: "C"},
                },
                2: {
                    "coords": np.array([2.866, 0.25, 0.0]),
                    "element": "C",
                    "bond_to": {1: "O", 3: "C", 4: "C"},
                },
                3: {
                    "coords": np.array([2.0, 0.75, 0.0]),
                    "element": "C",
                    "bond_to": {2: "C", 5: "H", 6: "H", 7: "H"},
                },
                4: {
                    "coords": np.array([2.866, -0.75, 0.0]),
                    "element": "C",
                    "bond_to": {2: "C", 8: "H", 9: "H", 10: "H"},
                },
                5: {
                    "coords": np.array([2.31, 1.2869, 0.0]),
                    "element": "H",
                    "bond_to": {3: "C"},
                },
                6: {
                    "coords": np.array([1.4631, 1.06, 0.0]),
                    "element": "H",
                    "bond_to": {3: "C"},
                },
                7: {
                    "coords": np.array([1.69, 0.2131, 0.0]),
                    "element": "H",
                    "bond_to": {3: "C"},
                },
                8: {
                    "coords": np.array([2.246, -0.75, 0.0]),
                    "element": "H",
                    "bond_to": {4: "C"},
                },
                9: {
                    "coords": np.array([2.866, -1.37, 0.0]),
                    "element": "H",
                    "bond_to": {4: "C"},
                },
                10: {
                    "coords": np.array([3.486, -0.75, 0.0]),
                    "element": "H",
                    "bond_to": {4: "C"},
                },
            },
            {
                1: {
                    "to_atom_index": 1,
                    "from_atom_index": 2,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                2: {
                    "to_atom_index": 2,
                    "from_atom_index": 3,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                3: {
                    "to_atom_index": 2,
                    "from_atom_index": 4,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                4: {
                    "to_atom_index": 3,
                    "from_atom_index": 5,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                5: {
                    "to_atom_index": 3,
                    "from_atom_index": 6,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                6: {
                    "to_atom_index": 3,
                    "from_atom_index": 7,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                7: {
                    "to_atom_index": 4,
                    "from_atom_index": 8,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                8: {
                    "to_atom_index": 4,
                    "from_atom_index": 9,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                9: {
                    "to_atom_index": 4,
                    "from_atom_index": 10,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
            },
        )

    @pytest.fixture
    def acetone_3d_molecule_data(self):
        return (
            {
                1: {
                    "coords": np.array([3.0000e-04, -1.3171e00, -2.0000e-04]),
                    "element": "O",
                    "bond_to": {2: "C"},
                },
                2: {
                    "coords": np.array([0.0, -0.0872, 0.0006]),
                    "element": "C",
                    "bond_to": {1: "O", 3: "C", 4: "C"},
                },
                3: {
                    "coords": np.array([1.281e00, 7.024e-01, -2.000e-04]),
                    "element": "C",
                    "bond_to": {2: "C", 5: "H", 6: "H", 7: "H"},
                },
                4: {
                    "coords": np.array([-1.2813e00, 7.0190e-01, -2.0000e-04]),
                    "element": "C",
                    "bond_to": {2: "C", 8: "H", 9: "H", 10: "H"},
                },
                5: {
                    "coords": np.array([1.3279, 1.3235, -0.898]),
                    "element": "H",
                    "bond_to": {3: "C"},
                },
                6: {
                    "coords": np.array([1.326, 1.3282, 0.8945]),
                    "element": "H",
                    "bond_to": {3: "C"},
                },
                7: {
                    "coords": np.array([2.1351, 0.0196, 0.0027]),
                    "element": "H",
                    "bond_to": {3: "C"},
                },
                8: {
                    "coords": np.array([-2.1352, 0.0187, 0.0027]),
                    "element": "H",
                    "bond_to": {4: "C"},
                },
                9: {
                    "coords": np.array([-1.3284, 1.323, -0.898]),
                    "element": "H",
                    "bond_to": {4: "C"},
                },
                10: {
                    "coords": np.array([-1.3266, 1.3278, 0.8945]),
                    "element": "H",
                    "bond_to": {4: "C"},
                },
            },
            {
                1: {
                    "to_atom_index": 1,
                    "from_atom_index": 2,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                2: {
                    "to_atom_index": 2,
                    "from_atom_index": 3,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                3: {
                    "to_atom_index": 2,
                    "from_atom_index": 4,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                4: {
                    "to_atom_index": 3,
                    "from_atom_index": 5,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                5: {
                    "to_atom_index": 3,
                    "from_atom_index": 6,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                6: {
                    "to_atom_index": 3,
                    "from_atom_index": 7,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                7: {
                    "to_atom_index": 4,
                    "from_atom_index": 8,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                8: {
                    "to_atom_index": 4,
                    "from_atom_index": 9,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                9: {
                    "to_atom_index": 4,
                    "from_atom_index": 10,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
            },
        )

    @pytest.fixture
    def morphine_2d_molecule_data(self):
        return (
            {
                1: {
                    "coords": np.array([2.2314, 0.0528, 0.0]),
                    "element": "O",
                    "bond_to": {8: "C", 16: "C"},
                },
                2: {
                    "coords": np.array([2.0, -2.4021, 0.0]),
                    "element": "O",
                    "bond_to": {14: "C", 39: "H"},
                },
                3: {
                    "coords": np.array([2.0, 2.4021, 0.0]),
                    "element": "O",
                    "bond_to": {20: "C", 40: "H"},
                },
                4: {
                    "coords": np.array([6.1607, -0.9511, 0.0]),
                    "element": "N",
                    "bond_to": {7: "C", 12: "C", 18: "C"},
                },
                5: {
                    "coords": np.array([3.6897, -0.4755, 0.0]),
                    "element": "C",
                    "bond_to": {6: "C", 8: "C", 9: "C", 10: "C"},
                },
                6: {
                    "coords": np.array([4.5133, -0.9511, 0.0]),
                    "element": "C",
                    "bond_to": {5: "C", 7: "C", 15: "C", 22: "H"},
                },
                7: {
                    "coords": np.array([5.337, -0.4755, 0.0]),
                    "element": "C",
                    "bond_to": {4: "N", 6: "C", 11: "C", 23: "H"},
                },
                8: {
                    "coords": np.array([2.866, -0.9511, 0.0]),
                    "element": "C",
                    "bond_to": {1: "O", 5: "C", 14: "C", 24: "H"},
                },
                9: {
                    "coords": np.array([4.2392, 0.2219, 0.0]),
                    "element": "C",
                    "bond_to": {5: "C", 12: "C", 25: "H", 26: "H"},
                },
                10: {
                    "coords": np.array([3.6897, 0.4755, 0.0]),
                    "element": "C",
                    "bond_to": {5: "C", 13: "C", 16: "C"},
                },
                11: {
                    "coords": np.array([5.337, 0.4755, 0.0]),
                    "element": "C",
                    "bond_to": {7: "C", 13: "C", 27: "H", 28: "H"},
                },
                12: {
                    "coords": np.array([5.5918, 0.2219, 0.0]),
                    "element": "C",
                    "bond_to": {4: "N", 9: "C", 29: "H", 30: "H"},
                },
                13: {
                    "coords": np.array([4.5133, 0.9511, 0.0]),
                    "element": "C",
                    "bond_to": {10: "C", 11: "C", 19: "C"},
                },
                14: {
                    "coords": np.array([2.866, -1.9022, 0.0]),
                    "element": "C",
                    "bond_to": {2: "O", 8: "C", 17: "C", 31: "H"},
                },
                15: {
                    "coords": np.array([4.5133, -1.9022, 0.0]),
                    "element": "C",
                    "bond_to": {6: "C", 17: "C", 32: "H"},
                },
                16: {
                    "coords": np.array([2.866, 0.9511, 0.0]),
                    "element": "C",
                    "bond_to": {1: "O", 10: "C", 20: "C"},
                },
                17: {
                    "coords": np.array([3.6897, -2.3777, 0.0]),
                    "element": "C",
                    "bond_to": {14: "C", 15: "C", 33: "H"},
                },
                18: {
                    "coords": np.array([6.8418, -1.6832, 0.0]),
                    "element": "C",
                    "bond_to": {4: "N", 34: "H", 35: "H", 36: "H"},
                },
                19: {
                    "coords": np.array([4.5133, 1.9022, 0.0]),
                    "element": "C",
                    "bond_to": {13: "C", 21: "C", 37: "H"},
                },
                20: {
                    "coords": np.array([2.866, 1.9022, 0.0]),
                    "element": "C",
                    "bond_to": {3: "O", 16: "C", 21: "C"},
                },
                21: {
                    "coords": np.array([3.6897, 2.3777, 0.0]),
                    "element": "C",
                    "bond_to": {19: "C", 20: "C", 38: "H"},
                },
                22: {
                    "coords": np.array([5.0597, -1.6022, 0.0]),
                    "element": "H",
                    "bond_to": {6: "C"},
                },
                23: {
                    "coords": np.array([5.6284, -1.274, 0.0]),
                    "element": "H",
                    "bond_to": {7: "C"},
                },
                24: {
                    "coords": np.array([2.0496, -1.1875, 0.0]),
                    "element": "H",
                    "bond_to": {8: "C"},
                },
                25: {
                    "coords": np.array([4.376, 0.8266, 0.0]),
                    "element": "H",
                    "bond_to": {9: "C"},
                },
                26: {
                    "coords": np.array([3.6795, 0.4887, 0.0]),
                    "element": "H",
                    "bond_to": {9: "C"},
                },
                27: {
                    "coords": np.array([5.9476, 0.3679, 0.0]),
                    "element": "H",
                    "bond_to": {11: "C"},
                },
                28: {
                    "coords": np.array([5.549, 1.0581, 0.0]),
                    "element": "H",
                    "bond_to": {11: "C"},
                },
                29: {
                    "coords": np.array([6.184, 0.4057, 0.0]),
                    "element": "H",
                    "bond_to": {12: "C"},
                },
                30: {
                    "coords": np.array([5.4989, 0.8349, 0.0]),
                    "element": "H",
                    "bond_to": {12: "C"},
                },
                31: {
                    "coords": np.array([2.866, -2.5222, 0.0]),
                    "element": "H",
                    "bond_to": {14: "C"},
                },
                32: {
                    "coords": np.array([5.0503, -2.2122, 0.0]),
                    "element": "H",
                    "bond_to": {15: "C"},
                },
                33: {
                    "coords": np.array([3.6897, -2.9977, 0.0]),
                    "element": "H",
                    "bond_to": {17: "C"},
                },
                34: {
                    "coords": np.array([6.3879, -2.1055, 0.0]),
                    "element": "H",
                    "bond_to": {18: "C"},
                },
                35: {
                    "coords": np.array([7.2641, -2.1371, 0.0]),
                    "element": "H",
                    "bond_to": {18: "C"},
                },
                36: {
                    "coords": np.array([7.2957, -1.2609, 0.0]),
                    "element": "H",
                    "bond_to": {18: "C"},
                },
                37: {
                    "coords": np.array([5.0503, 2.2122, 0.0]),
                    "element": "H",
                    "bond_to": {19: "C"},
                },
                38: {
                    "coords": np.array([3.6897, 2.9977, 0.0]),
                    "element": "H",
                    "bond_to": {21: "C"},
                },
                39: {
                    "coords": np.array([2.0, -3.0222, 0.0]),
                    "element": "H",
                    "bond_to": {2: "O"},
                },
                40: {
                    "coords": np.array([2.0, 3.0222, 0.0]),
                    "element": "H",
                    "bond_to": {3: "O"},
                },
            },
            {
                1: {
                    "to_atom_index": 1,
                    "from_atom_index": 8,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                2: {
                    "to_atom_index": 1,
                    "from_atom_index": 16,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                3: {
                    "to_atom_index": 14,
                    "from_atom_index": 2,
                    "bond_type": "1",
                    "stereo": 6,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                32: {
                    "to_atom_index": 14,
                    "from_atom_index": 17,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                33: {
                    "to_atom_index": 14,
                    "from_atom_index": 31,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                4: {
                    "to_atom_index": 2,
                    "from_atom_index": 39,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                5: {
                    "to_atom_index": 3,
                    "from_atom_index": 20,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                6: {
                    "to_atom_index": 3,
                    "from_atom_index": 40,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                7: {
                    "to_atom_index": 4,
                    "from_atom_index": 7,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                8: {
                    "to_atom_index": 4,
                    "from_atom_index": 12,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                9: {
                    "to_atom_index": 4,
                    "from_atom_index": 18,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                10: {
                    "to_atom_index": 5,
                    "from_atom_index": 6,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                11: {
                    "to_atom_index": 5,
                    "from_atom_index": 8,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                12: {
                    "to_atom_index": 5,
                    "from_atom_index": 9,
                    "bond_type": "1",
                    "stereo": 1,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                13: {
                    "to_atom_index": 5,
                    "from_atom_index": 10,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                14: {
                    "to_atom_index": 6,
                    "from_atom_index": 7,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                15: {
                    "to_atom_index": 6,
                    "from_atom_index": 15,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                16: {
                    "to_atom_index": 6,
                    "from_atom_index": 22,
                    "bond_type": "1",
                    "stereo": 1,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                17: {
                    "to_atom_index": 7,
                    "from_atom_index": 11,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                18: {
                    "to_atom_index": 7,
                    "from_atom_index": 23,
                    "bond_type": "1",
                    "stereo": 6,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                19: {
                    "to_atom_index": 8,
                    "from_atom_index": 14,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                20: {
                    "to_atom_index": 8,
                    "from_atom_index": 24,
                    "bond_type": "1",
                    "stereo": 1,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                21: {
                    "to_atom_index": 9,
                    "from_atom_index": 12,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                22: {
                    "to_atom_index": 9,
                    "from_atom_index": 25,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                23: {
                    "to_atom_index": 9,
                    "from_atom_index": 26,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                24: {
                    "to_atom_index": 10,
                    "from_atom_index": 13,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                25: {
                    "to_atom_index": 10,
                    "from_atom_index": 16,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                26: {
                    "to_atom_index": 11,
                    "from_atom_index": 13,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                27: {
                    "to_atom_index": 11,
                    "from_atom_index": 27,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                28: {
                    "to_atom_index": 11,
                    "from_atom_index": 28,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                29: {
                    "to_atom_index": 12,
                    "from_atom_index": 29,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                30: {
                    "to_atom_index": 12,
                    "from_atom_index": 30,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                31: {
                    "to_atom_index": 13,
                    "from_atom_index": 19,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                34: {
                    "to_atom_index": 15,
                    "from_atom_index": 17,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                35: {
                    "to_atom_index": 15,
                    "from_atom_index": 32,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                36: {
                    "to_atom_index": 16,
                    "from_atom_index": 20,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                37: {
                    "to_atom_index": 17,
                    "from_atom_index": 33,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                38: {
                    "to_atom_index": 18,
                    "from_atom_index": 34,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                39: {
                    "to_atom_index": 18,
                    "from_atom_index": 35,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                40: {
                    "to_atom_index": 18,
                    "from_atom_index": 36,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                41: {
                    "to_atom_index": 19,
                    "from_atom_index": 21,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                42: {
                    "to_atom_index": 19,
                    "from_atom_index": 37,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                43: {
                    "to_atom_index": 20,
                    "from_atom_index": 21,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                44: {
                    "to_atom_index": 21,
                    "from_atom_index": 38,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
            },
        )

    @pytest.fixture
    def morphine_3d_molecule_data(self):
        return (
            {
                1: {
                    "coords": np.array([-1.993, -0.474, 1.2005]),
                    "element": "O",
                    "bond_to": {8: "C", 16: "C"},
                },
                2: {
                    "coords": np.array([-2.7826, -2.5168, -0.2218]),
                    "element": "O",
                    "bond_to": {14: "C", 39: "H"},
                },
                3: {
                    "coords": np.array([-3.622, 1.8421, 0.5579]),
                    "element": "O",
                    "bond_to": {20: "C", 40: "H"},
                },
                4: {
                    "coords": np.array([3.1777, -0.0101, 0.4474]),
                    "element": "N",
                    "bond_to": {7: "C", 12: "C", 18: "C"},
                },
                5: {
                    "coords": np.array([0.3699, -0.7149, 0.6616]),
                    "element": "C",
                    "bond_to": {6: "C", 8: "C", 9: "C", 10: "C"},
                },
                6: {
                    "coords": np.array([1.2913, -1.3046, -0.417]),
                    "element": "C",
                    "bond_to": {5: "C", 7: "C", 15: "C", 22: "H"},
                },
                7: {
                    "coords": np.array([2.3441, -0.2023, -0.764]),
                    "element": "C",
                    "bond_to": {4: "N", 6: "C", 11: "C", 23: "H"},
                },
                8: {
                    "coords": np.array([-0.9377, -1.475, 0.9848]),
                    "element": "C",
                    "bond_to": {1: "O", 5: "C", 14: "C", 24: "H"},
                },
                9: {
                    "coords": np.array([1.1988, -0.3907, 1.9201]),
                    "element": "C",
                    "bond_to": {5: "C", 12: "C", 25: "H", 26: "H"},
                },
                10: {
                    "coords": np.array([-0.2516, 0.5302, 0.1205]),
                    "element": "C",
                    "bond_to": {5: "C", 13: "C", 16: "C"},
                },
                11: {
                    "coords": np.array([1.6887, 1.1052, -1.3279]),
                    "element": "C",
                    "bond_to": {7: "C", 13: "C", 27: "H", 28: "H"},
                },
                12: {
                    "coords": np.array([2.4315, 0.4754, 1.6126]),
                    "element": "C",
                    "bond_to": {4: "N", 9: "C", 29: "H", 30: "H"},
                },
                13: {
                    "coords": np.array([0.3384, 1.4306, -0.748]),
                    "element": "C",
                    "bond_to": {10: "C", 11: "C", 19: "C"},
                },
                14: {
                    "coords": np.array([-1.3631, -2.5067, -0.0924]),
                    "element": "C",
                    "bond_to": {2: "O", 8: "C", 17: "C", 31: "H"},
                },
                15: {
                    "coords": np.array([0.5066, -1.8183, -1.5971]),
                    "element": "C",
                    "bond_to": {6: "C", 17: "C", 32: "H"},
                },
                16: {
                    "coords": np.array([-1.5672, 0.6306, 0.5136]),
                    "element": "C",
                    "bond_to": {1: "O", 10: "C", 20: "C"},
                },
                17: {
                    "coords": np.array([-0.7155, -2.3492, -1.4425]),
                    "element": "C",
                    "bond_to": {14: "C", 15: "C", 33: "H"},
                },
                18: {
                    "coords": np.array([4.3733, 0.7916, 0.2084]),
                    "element": "C",
                    "bond_to": {4: "N", 34: "H", 35: "H", 36: "H"},
                },
                19: {
                    "coords": np.array([-0.4184, 2.5415, -1.1246]),
                    "element": "C",
                    "bond_to": {13: "C", 21: "C", 37: "H"},
                },
                20: {
                    "coords": np.array([-2.331, 1.7217, 0.162]),
                    "element": "C",
                    "bond_to": {3: "O", 16: "C", 21: "C"},
                },
                21: {
                    "coords": np.array([-1.7382, 2.6936, -0.6541]),
                    "element": "C",
                    "bond_to": {19: "C", 20: "C", 38: "H"},
                },
                22: {
                    "coords": np.array([1.8278, -2.1759, -0.0118]),
                    "element": "H",
                    "bond_to": {6: "C"},
                },
                23: {
                    "coords": np.array([3.0029, -0.6035, -1.5465]),
                    "element": "H",
                    "bond_to": {7: "C"},
                },
                24: {
                    "coords": np.array([-0.8451, -2.0128, 1.9373]),
                    "element": "H",
                    "bond_to": {8: "C"},
                },
                25: {
                    "coords": np.array([1.5366, -1.3335, 2.3712]),
                    "element": "H",
                    "bond_to": {9: "C"},
                },
                26: {
                    "coords": np.array([0.5899, 0.1174, 2.679]),
                    "element": "H",
                    "bond_to": {9: "C"},
                },
                27: {
                    "coords": np.array([1.5474, 0.9596, -2.4075]),
                    "element": "H",
                    "bond_to": {11: "C"},
                },
                28: {
                    "coords": np.array([2.353, 1.968, -1.2194]),
                    "element": "H",
                    "bond_to": {11: "C"},
                },
                29: {
                    "coords": np.array([2.1271, 1.5205, 1.476]),
                    "element": "H",
                    "bond_to": {12: "C"},
                },
                30: {
                    "coords": np.array([3.0801, 0.4584, 2.4975]),
                    "element": "H",
                    "bond_to": {12: "C"},
                },
                31: {
                    "coords": np.array([-1.0772, -3.5067, 0.2593]),
                    "element": "H",
                    "bond_to": {14: "C"},
                },
                32: {
                    "coords": np.array([0.9601, -1.7947, -2.5831]),
                    "element": "H",
                    "bond_to": {15: "C"},
                },
                33: {
                    "coords": np.array([-1.23, -2.7505, -2.3109]),
                    "element": "H",
                    "bond_to": {17: "C"},
                },
                34: {
                    "coords": np.array([4.15, 1.8479, 0.0287]),
                    "element": "H",
                    "bond_to": {18: "C"},
                },
                35: {
                    "coords": np.array([4.938, 0.4055, -0.6472]),
                    "element": "H",
                    "bond_to": {18: "C"},
                },
                36: {
                    "coords": np.array([5.0444, 0.7352, 1.073]),
                    "element": "H",
                    "bond_to": {18: "C"},
                },
                37: {
                    "coords": np.array([-0.0062, 3.2824, -1.8043]),
                    "element": "H",
                    "bond_to": {19: "C"},
                },
                38: {
                    "coords": np.array([-2.3121, 3.5638, -0.9645]),
                    "element": "H",
                    "bond_to": {21: "C"},
                },
                39: {
                    "coords": np.array([-3.1557, -2.6446, 0.6672]),
                    "element": "H",
                    "bond_to": {2: "O"},
                },
                40: {
                    "coords": np.array([-3.8483, 1.0686, 1.1031]),
                    "element": "H",
                    "bond_to": {3: "O"},
                },
            },
            {
                1: {
                    "to_atom_index": 1,
                    "from_atom_index": 8,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                2: {
                    "to_atom_index": 1,
                    "from_atom_index": 16,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                3: {
                    "to_atom_index": 2,
                    "from_atom_index": 14,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                4: {
                    "to_atom_index": 2,
                    "from_atom_index": 39,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                5: {
                    "to_atom_index": 3,
                    "from_atom_index": 20,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                6: {
                    "to_atom_index": 3,
                    "from_atom_index": 40,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                7: {
                    "to_atom_index": 4,
                    "from_atom_index": 7,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                8: {
                    "to_atom_index": 4,
                    "from_atom_index": 12,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                9: {
                    "to_atom_index": 4,
                    "from_atom_index": 18,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                10: {
                    "to_atom_index": 5,
                    "from_atom_index": 6,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                11: {
                    "to_atom_index": 5,
                    "from_atom_index": 8,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                12: {
                    "to_atom_index": 5,
                    "from_atom_index": 9,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                13: {
                    "to_atom_index": 5,
                    "from_atom_index": 10,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                14: {
                    "to_atom_index": 6,
                    "from_atom_index": 7,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                15: {
                    "to_atom_index": 6,
                    "from_atom_index": 15,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                16: {
                    "to_atom_index": 6,
                    "from_atom_index": 22,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                17: {
                    "to_atom_index": 7,
                    "from_atom_index": 11,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                18: {
                    "to_atom_index": 7,
                    "from_atom_index": 23,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                19: {
                    "to_atom_index": 8,
                    "from_atom_index": 14,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                20: {
                    "to_atom_index": 8,
                    "from_atom_index": 24,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                21: {
                    "to_atom_index": 9,
                    "from_atom_index": 12,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                22: {
                    "to_atom_index": 9,
                    "from_atom_index": 25,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                23: {
                    "to_atom_index": 9,
                    "from_atom_index": 26,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                24: {
                    "to_atom_index": 10,
                    "from_atom_index": 13,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                25: {
                    "to_atom_index": 10,
                    "from_atom_index": 16,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                26: {
                    "to_atom_index": 11,
                    "from_atom_index": 13,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                27: {
                    "to_atom_index": 11,
                    "from_atom_index": 27,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                28: {
                    "to_atom_index": 11,
                    "from_atom_index": 28,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                29: {
                    "to_atom_index": 12,
                    "from_atom_index": 29,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                30: {
                    "to_atom_index": 12,
                    "from_atom_index": 30,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                31: {
                    "to_atom_index": 13,
                    "from_atom_index": 19,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                32: {
                    "to_atom_index": 14,
                    "from_atom_index": 17,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                33: {
                    "to_atom_index": 14,
                    "from_atom_index": 31,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                34: {
                    "to_atom_index": 15,
                    "from_atom_index": 17,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                35: {
                    "to_atom_index": 15,
                    "from_atom_index": 32,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                36: {
                    "to_atom_index": 16,
                    "from_atom_index": 20,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                37: {
                    "to_atom_index": 17,
                    "from_atom_index": 33,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                38: {
                    "to_atom_index": 18,
                    "from_atom_index": 34,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                39: {
                    "to_atom_index": 18,
                    "from_atom_index": 35,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                40: {
                    "to_atom_index": 18,
                    "from_atom_index": 36,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                41: {
                    "to_atom_index": 19,
                    "from_atom_index": 21,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                42: {
                    "to_atom_index": 19,
                    "from_atom_index": 37,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                43: {
                    "to_atom_index": 20,
                    "from_atom_index": 21,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                44: {
                    "to_atom_index": 21,
                    "from_atom_index": 38,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
            },
        )

    @pytest.fixture
    def heme_2d_molecule_data(self):
        return (
            {
                1: {"coords": np.array([6.7437, 0.7222, 0.0]), "element": "Fe"},
                2: {
                    "coords": np.array([7.6407, -5.2892, 0.0]),
                    "element": "O",
                    "bond_to": {38: "C", 74: "H"},
                },
                3: {
                    "coords": np.array([13.2337, 0.2017, 0.0]),
                    "element": "O",
                    "bond_to": {39: "C", 75: "H"},
                },
                4: {
                    "coords": np.array([9.0357, -4.2626, 0.0]),
                    "element": "O",
                    "bond_to": {38: "C"},
                },
                5: {
                    "coords": np.array([12.191, -1.1813, 0.0]),
                    "element": "O",
                    "bond_to": {39: "C"},
                },
                6: {
                    "coords": np.array([6.7568, -0.2777, 0.0]),
                    "element": "N",
                    "bond_to": {12: "C", 18: "C"},
                },
                7: {
                    "coords": np.array([8.2586, 1.0918, 0.0]),
                    "element": "N",
                    "bond_to": {13: "C", 19: "C"},
                },
                8: {
                    "coords": np.array([5.2534, 1.0918, 0.0]),
                    "element": "N",
                    "bond_to": {25: "C", 33: "C"},
                },
                9: {
                    "coords": np.array([6.7233, 2.4613, 0.0]),
                    "element": "N",
                    "bond_to": {26: "C", 31: "C"},
                },
                10: {
                    "coords": np.array([7.2574, -1.8464, 0.0]),
                    "element": "C",
                    "bond_to": {12: "C", 14: "C", 16: "C"},
                },
                11: {
                    "coords": np.array([9.7955, 0.6247, 0.0]),
                    "element": "C",
                    "bond_to": {13: "C", 15: "C", 17: "C"},
                },
                12: {
                    "coords": np.array([7.5588, -0.8787, 0.0]),
                    "element": "C",
                    "bond_to": {6: "N", 10: "C", 20: "C"},
                },
                13: {
                    "coords": np.array([8.8596, 0.3568, 0.0]),
                    "element": "C",
                    "bond_to": {7: "N", 11: "C", 20: "C"},
                },
                14: {
                    "coords": np.array([6.2562, -1.8464, 0.0]),
                    "element": "C",
                    "bond_to": {10: "C", 18: "C", 27: "C"},
                },
                15: {
                    "coords": np.array([9.7955, 1.6259, 0.0]),
                    "element": "C",
                    "bond_to": {11: "C", 19: "C", 28: "C"},
                },
                16: {
                    "coords": np.array([7.8502, -2.6518, 0.0]),
                    "element": "C",
                    "bond_to": {10: "C", 23: "C", 44: "H", 45: "H"},
                },
                17: {
                    "coords": np.array([10.594, 0.0227, 0.0]),
                    "element": "C",
                    "bond_to": {11: "C", 24: "C", 46: "H", 47: "H"},
                },
                18: {
                    "coords": np.array([5.9549, -0.9122, 0.0]),
                    "element": "C",
                    "bond_to": {6: "N", 14: "C", 21: "C"},
                },
                19: {
                    "coords": np.array([8.8261, 1.8938, 0.0]),
                    "element": "C",
                    "bond_to": {7: "N", 15: "C", 22: "C"},
                },
                20: {
                    "coords": np.array([8.5599, -0.6109, 0.0]),
                    "element": "C",
                    "bond_to": {12: "C", 13: "C", 48: "H"},
                },
                21: {
                    "coords": np.array([4.9872, -0.6109, 0.0]),
                    "element": "C",
                    "bond_to": {18: "C", 25: "C", 49: "H"},
                },
                22: {
                    "coords": np.array([8.5265, 2.828, 0.0]),
                    "element": "C",
                    "bond_to": {19: "C", 26: "C", 50: "H"},
                },
                23: {
                    "coords": np.array([7.4491, -3.5678, 0.0]),
                    "element": "C",
                    "bond_to": {16: "C", 38: "C", 51: "H", 52: "H"},
                },
                24: {
                    "coords": np.array([11.5146, 0.4132, 0.0]),
                    "element": "C",
                    "bond_to": {17: "C", 39: "C", 53: "H", 54: "H"},
                },
                25: {
                    "coords": np.array([4.6858, 0.3233, 0.0]),
                    "element": "C",
                    "bond_to": {8: "N", 21: "C", 29: "C"},
                },
                26: {
                    "coords": np.array([7.5588, 3.1293, 0.0]),
                    "element": "C",
                    "bond_to": {9: "N", 22: "C", 30: "C"},
                },
                27: {
                    "coords": np.array([5.5855, -2.5881, 0.0]),
                    "element": "C",
                    "bond_to": {14: "C", 55: "H", 56: "H", 57: "H"},
                },
                28: {
                    "coords": np.array([10.5912, 2.2315, 0.0]),
                    "element": "C",
                    "bond_to": {15: "C", 58: "H", 59: "H", 60: "H"},
                },
                29: {
                    "coords": np.array([3.7182, 0.5912, 0.0]),
                    "element": "C",
                    "bond_to": {25: "C", 34: "C", 36: "C"},
                },
                30: {
                    "coords": np.array([7.2239, 4.0635, 0.0]),
                    "element": "C",
                    "bond_to": {26: "C", 32: "C", 40: "C"},
                },
                31: {
                    "coords": np.array([5.9214, 3.0958, 0.0]),
                    "element": "C",
                    "bond_to": {9: "N", 32: "C", 35: "C"},
                },
                32: {
                    "coords": np.array([6.2228, 4.0635, 0.0]),
                    "element": "C",
                    "bond_to": {30: "C", 31: "C", 37: "C"},
                },
                33: {
                    "coords": np.array([4.6858, 1.8603, 0.0]),
                    "element": "C",
                    "bond_to": {8: "N", 34: "C", 35: "C"},
                },
                34: {
                    "coords": np.array([3.7182, 1.5924, 0.0]),
                    "element": "C",
                    "bond_to": {29: "C", 33: "C", 41: "C"},
                },
                35: {
                    "coords": np.array([4.9537, 2.828, 0.0]),
                    "element": "C",
                    "bond_to": {31: "C", 33: "C", 61: "H"},
                },
                36: {
                    "coords": np.array([2.8521, 0.0912, 0.0]),
                    "element": "C",
                    "bond_to": {29: "C", 62: "H", 63: "H", 64: "H"},
                },
                37: {
                    "coords": np.array([5.63, 4.8689, 0.0]),
                    "element": "C",
                    "bond_to": {32: "C", 65: "H", 66: "H", 67: "H"},
                },
                38: {
                    "coords": np.array([8.0418, -4.3732, 0.0]),
                    "element": "C",
                    "bond_to": {2: "O", 4: "O", 23: "C"},
                },
                39: {
                    "coords": np.array([12.3131, -0.1888, 0.0]),
                    "element": "C",
                    "bond_to": {3: "O", 5: "O", 24: "C"},
                },
                40: {
                    "coords": np.array([7.7995, 4.8812, 0.0]),
                    "element": "C",
                    "bond_to": {30: "C", 42: "C", 68: "H"},
                },
                41: {
                    "coords": np.array([2.9223, 2.1979, 0.0]),
                    "element": "C",
                    "bond_to": {34: "C", 43: "C", 69: "H"},
                },
                42: {
                    "coords": np.array([7.3791, 5.7886, 0.0]),
                    "element": "C",
                    "bond_to": {40: "C", 70: "H", 71: "H"},
                },
                43: {
                    "coords": np.array([2.0, 1.8114, 0.0]),
                    "element": "C",
                    "bond_to": {41: "C", 72: "H", 73: "H"},
                },
                44: {
                    "coords": np.array([8.3663, -2.9953, 0.0]),
                    "element": "H",
                    "bond_to": {16: "C"},
                },
                45: {
                    "coords": np.array([8.2781, -2.2032, 0.0]),
                    "element": "H",
                    "bond_to": {16: "C"},
                },
                46: {
                    "coords": np.array([10.1405, -0.4, 0.0]),
                    "element": "H",
                    "bond_to": {17: "C"},
                },
                47: {
                    "coords": np.array([10.9316, -0.4974, 0.0]),
                    "element": "H",
                    "bond_to": {17: "C"},
                },
                48: {
                    "coords": np.array([8.9897, -1.0577, 0.0]),
                    "element": "H",
                    "bond_to": {20: "C"},
                },
                49: {
                    "coords": np.array([4.551, -1.0515, 0.0]),
                    "element": "H",
                    "bond_to": {21: "C"},
                },
                50: {
                    "coords": np.array([8.963, 3.2682, 0.0]),
                    "element": "H",
                    "bond_to": {22: "C"},
                },
                51: {
                    "coords": np.array([6.9329, -3.2243, 0.0]),
                    "element": "H",
                    "bond_to": {23: "C"},
                },
                52: {
                    "coords": np.array([7.0211, -4.0165, 0.0]),
                    "element": "H",
                    "bond_to": {23: "C"},
                },
                53: {
                    "coords": np.array([11.9681, 0.8359, 0.0]),
                    "element": "H",
                    "bond_to": {24: "C"},
                },
                54: {
                    "coords": np.array([11.177, 0.9333, 0.0]),
                    "element": "H",
                    "bond_to": {24: "C"},
                },
                55: {
                    "coords": np.array([5.1257, -2.1723, 0.0]),
                    "element": "H",
                    "bond_to": {27: "C"},
                },
                56: {
                    "coords": np.array([5.1697, -3.048, 0.0]),
                    "element": "H",
                    "bond_to": {27: "C"},
                },
                57: {
                    "coords": np.array([6.0454, -3.004, 0.0]),
                    "element": "H",
                    "bond_to": {27: "C"},
                },
                58: {
                    "coords": np.array([10.9667, 1.7382, 0.0]),
                    "element": "H",
                    "bond_to": {28: "C"},
                },
                59: {
                    "coords": np.array([11.0846, 2.607, 0.0]),
                    "element": "H",
                    "bond_to": {28: "C"},
                },
                60: {
                    "coords": np.array([10.2157, 2.7249, 0.0]),
                    "element": "H",
                    "bond_to": {28: "C"},
                },
                61: {
                    "coords": np.array([4.5153, 3.2664, 0.0]),
                    "element": "H",
                    "bond_to": {35: "C"},
                },
                62: {
                    "coords": np.array([2.5421, 0.6281, 0.0]),
                    "element": "H",
                    "bond_to": {36: "C"},
                },
                63: {
                    "coords": np.array([2.3152, -0.2188, 0.0]),
                    "element": "H",
                    "bond_to": {36: "C"},
                },
                64: {
                    "coords": np.array([3.1622, -0.4457, 0.0]),
                    "element": "H",
                    "bond_to": {36: "C"},
                },
                65: {
                    "coords": np.array([6.1293, 5.2364, 0.0]),
                    "element": "H",
                    "bond_to": {37: "C"},
                },
                66: {
                    "coords": np.array([5.2625, 5.3682, 0.0]),
                    "element": "H",
                    "bond_to": {37: "C"},
                },
                67: {
                    "coords": np.array([5.1307, 4.5014, 0.0]),
                    "element": "H",
                    "bond_to": {37: "C"},
                },
                68: {
                    "coords": np.array([8.417, 4.8257, 0.0]),
                    "element": "H",
                    "bond_to": {40: "C"},
                },
                69: {
                    "coords": np.array([3.0007, 2.8129, 0.0]),
                    "element": "H",
                    "bond_to": {41: "C"},
                },
                70: {
                    "coords": np.array([7.736, 6.2956, 0.0]),
                    "element": "H",
                    "bond_to": {42: "C"},
                },
                71: {
                    "coords": np.array([6.7616, 5.8441, 0.0]),
                    "element": "H",
                    "bond_to": {42: "C"},
                },
                72: {
                    "coords": np.array([1.5066, 2.1868, 0.0]),
                    "element": "H",
                    "bond_to": {43: "C"},
                },
                73: {
                    "coords": np.array([1.9216, 1.1963, 0.0]),
                    "element": "H",
                    "bond_to": {43: "C"},
                },
                74: {
                    "coords": np.array([8.0082, -5.7886, 0.0]),
                    "element": "H",
                    "bond_to": {2: "O"},
                },
                75: {
                    "coords": np.array([13.7288, -0.1715, 0.0]),
                    "element": "H",
                    "bond_to": {3: "O"},
                },
            },
            {
                1: {
                    "to_atom_index": 2,
                    "from_atom_index": 38,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                2: {
                    "to_atom_index": 2,
                    "from_atom_index": 74,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                3: {
                    "to_atom_index": 3,
                    "from_atom_index": 39,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                4: {
                    "to_atom_index": 3,
                    "from_atom_index": 75,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                5: {
                    "to_atom_index": 4,
                    "from_atom_index": 38,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                6: {
                    "to_atom_index": 5,
                    "from_atom_index": 39,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                7: {
                    "to_atom_index": 6,
                    "from_atom_index": 12,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                8: {
                    "to_atom_index": 6,
                    "from_atom_index": 18,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                9: {
                    "to_atom_index": 7,
                    "from_atom_index": 13,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                10: {
                    "to_atom_index": 7,
                    "from_atom_index": 19,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                11: {
                    "to_atom_index": 8,
                    "from_atom_index": 25,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                12: {
                    "to_atom_index": 8,
                    "from_atom_index": 33,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                13: {
                    "to_atom_index": 9,
                    "from_atom_index": 26,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                14: {
                    "to_atom_index": 9,
                    "from_atom_index": 31,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                15: {
                    "to_atom_index": 10,
                    "from_atom_index": 12,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                16: {
                    "to_atom_index": 10,
                    "from_atom_index": 14,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                17: {
                    "to_atom_index": 10,
                    "from_atom_index": 16,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                18: {
                    "to_atom_index": 11,
                    "from_atom_index": 13,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                19: {
                    "to_atom_index": 11,
                    "from_atom_index": 15,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                20: {
                    "to_atom_index": 11,
                    "from_atom_index": 17,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                21: {
                    "to_atom_index": 12,
                    "from_atom_index": 20,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                22: {
                    "to_atom_index": 13,
                    "from_atom_index": 20,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                23: {
                    "to_atom_index": 14,
                    "from_atom_index": 18,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                24: {
                    "to_atom_index": 14,
                    "from_atom_index": 27,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                25: {
                    "to_atom_index": 15,
                    "from_atom_index": 19,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                26: {
                    "to_atom_index": 15,
                    "from_atom_index": 28,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                27: {
                    "to_atom_index": 16,
                    "from_atom_index": 23,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                28: {
                    "to_atom_index": 16,
                    "from_atom_index": 44,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                29: {
                    "to_atom_index": 16,
                    "from_atom_index": 45,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                30: {
                    "to_atom_index": 17,
                    "from_atom_index": 24,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                31: {
                    "to_atom_index": 17,
                    "from_atom_index": 46,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                32: {
                    "to_atom_index": 17,
                    "from_atom_index": 47,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                33: {
                    "to_atom_index": 18,
                    "from_atom_index": 21,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                34: {
                    "to_atom_index": 19,
                    "from_atom_index": 22,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                35: {
                    "to_atom_index": 20,
                    "from_atom_index": 48,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                36: {
                    "to_atom_index": 21,
                    "from_atom_index": 25,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                37: {
                    "to_atom_index": 21,
                    "from_atom_index": 49,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                38: {
                    "to_atom_index": 22,
                    "from_atom_index": 26,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                39: {
                    "to_atom_index": 22,
                    "from_atom_index": 50,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                40: {
                    "to_atom_index": 23,
                    "from_atom_index": 38,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                41: {
                    "to_atom_index": 23,
                    "from_atom_index": 51,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                42: {
                    "to_atom_index": 23,
                    "from_atom_index": 52,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                43: {
                    "to_atom_index": 24,
                    "from_atom_index": 39,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                44: {
                    "to_atom_index": 24,
                    "from_atom_index": 53,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                45: {
                    "to_atom_index": 24,
                    "from_atom_index": 54,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                46: {
                    "to_atom_index": 25,
                    "from_atom_index": 29,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                47: {
                    "to_atom_index": 26,
                    "from_atom_index": 30,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                48: {
                    "to_atom_index": 27,
                    "from_atom_index": 55,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                49: {
                    "to_atom_index": 27,
                    "from_atom_index": 56,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                50: {
                    "to_atom_index": 27,
                    "from_atom_index": 57,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                51: {
                    "to_atom_index": 28,
                    "from_atom_index": 58,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                52: {
                    "to_atom_index": 28,
                    "from_atom_index": 59,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                53: {
                    "to_atom_index": 28,
                    "from_atom_index": 60,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                54: {
                    "to_atom_index": 29,
                    "from_atom_index": 34,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                55: {
                    "to_atom_index": 29,
                    "from_atom_index": 36,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                56: {
                    "to_atom_index": 30,
                    "from_atom_index": 32,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                57: {
                    "to_atom_index": 30,
                    "from_atom_index": 40,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                58: {
                    "to_atom_index": 31,
                    "from_atom_index": 32,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                59: {
                    "to_atom_index": 31,
                    "from_atom_index": 35,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                60: {
                    "to_atom_index": 32,
                    "from_atom_index": 37,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                61: {
                    "to_atom_index": 33,
                    "from_atom_index": 34,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                62: {
                    "to_atom_index": 33,
                    "from_atom_index": 35,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                63: {
                    "to_atom_index": 34,
                    "from_atom_index": 41,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                64: {
                    "to_atom_index": 35,
                    "from_atom_index": 61,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                65: {
                    "to_atom_index": 36,
                    "from_atom_index": 62,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                66: {
                    "to_atom_index": 36,
                    "from_atom_index": 63,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                67: {
                    "to_atom_index": 36,
                    "from_atom_index": 64,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                68: {
                    "to_atom_index": 37,
                    "from_atom_index": 65,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                69: {
                    "to_atom_index": 37,
                    "from_atom_index": 66,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                70: {
                    "to_atom_index": 37,
                    "from_atom_index": 67,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                71: {
                    "to_atom_index": 40,
                    "from_atom_index": 42,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                72: {
                    "to_atom_index": 40,
                    "from_atom_index": 68,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                73: {
                    "to_atom_index": 41,
                    "from_atom_index": 43,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                74: {
                    "to_atom_index": 41,
                    "from_atom_index": 69,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                75: {
                    "to_atom_index": 42,
                    "from_atom_index": 70,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                76: {
                    "to_atom_index": 42,
                    "from_atom_index": 71,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                77: {
                    "to_atom_index": 43,
                    "from_atom_index": 72,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                78: {
                    "to_atom_index": 43,
                    "from_atom_index": 73,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
            },
        )

    @pytest.fixture
    def heme_3d_molecule_data(self):
        return (
            {
                1: {
                    "coords": np.array([7.1385, 2.705, -0.6711]),
                    "element": "O",
                    "bond_to": {39: "C", 75: "H"},
                },
                2: {
                    "coords": np.array([5.7615, -3.2503, -2.9408]),
                    "element": "O",
                    "bond_to": {40: "C", 76: "H"},
                },
                3: {
                    "coords": np.array([6.7154, 2.1599, 1.493]),
                    "element": "O",
                    "bond_to": {39: "C"},
                },
                4: {
                    "coords": np.array([6.1372, -3.4886, -0.7132]),
                    "element": "O",
                    "bond_to": {40: "C"},
                },
                5: {
                    "coords": np.array([-2.525, 1.9272, 0.2862]),
                    "element": "N",
                    "bond_to": {17: "C", 20: "C", 50: "H"},
                },
                6: {
                    "coords": np.array([-2.6939, -1.118, 0.2758]),
                    "element": "N",
                    "bond_to": {18: "C", 19: "C", 51: "H"},
                },
                7: {
                    "coords": np.array([0.4051, 1.517, 0.2379]),
                    "element": "N",
                    "bond_to": {11: "C", 15: "C"},
                },
                8: {
                    "coords": np.array([0.1811, -1.3404, 0.4974]),
                    "element": "N",
                    "bond_to": {13: "C", 16: "C"},
                },
                9: {
                    "coords": np.array([2.507, 2.3377, 0.8711]),
                    "element": "C",
                    "bond_to": {11: "C", 12: "C", 21: "C"},
                },
                10: {
                    "coords": np.array([2.0591, -2.6167, 0.1996]),
                    "element": "C",
                    "bond_to": {13: "C", 14: "C", 22: "C"},
                },
                11: {
                    "coords": np.array([1.6482, 1.2058, 0.4657]),
                    "element": "C",
                    "bond_to": {7: "N", 9: "C", 23: "C"},
                },
                12: {
                    "coords": np.array([1.6304, 3.3517, 0.8618]),
                    "element": "C",
                    "bond_to": {9: "C", 15: "C", 31: "C"},
                },
                13: {
                    "coords": np.array([1.5429, -1.2639, 0.3342]),
                    "element": "C",
                    "bond_to": {8: "N", 10: "C", 23: "C"},
                },
                14: {
                    "coords": np.array([1.0549, -3.502, 0.2769]),
                    "element": "C",
                    "bond_to": {10: "C", 16: "C", 34: "C"},
                },
                15: {
                    "coords": np.array([0.3143, 2.872, 0.4652]),
                    "element": "C",
                    "bond_to": {7: "N", 12: "C", 28: "C"},
                },
                16: {
                    "coords": np.array([-0.1068, -2.6087, 0.4631]),
                    "element": "C",
                    "bond_to": {8: "N", 14: "C", 29: "C"},
                },
                17: {
                    "coords": np.array([-2.0505, 3.1577, -0.111]),
                    "element": "C",
                    "bond_to": {5: "N", 24: "C", 28: "C"},
                },
                18: {
                    "coords": np.array([-3.9963, -0.6924, 0.2747]),
                    "element": "C",
                    "bond_to": {6: "N", 25: "C", 30: "C"},
                },
                19: {
                    "coords": np.array([-2.5688, -2.4592, 0.54]),
                    "element": "C",
                    "bond_to": {6: "N", 27: "C", 29: "C"},
                },
                20: {
                    "coords": np.array([-3.7828, 1.7074, -0.2302]),
                    "element": "C",
                    "bond_to": {5: "N", 26: "C", 30: "C"},
                },
                21: {
                    "coords": np.array([3.9475, 2.2748, 1.2062]),
                    "element": "C",
                    "bond_to": {9: "C", 32: "C", 43: "H", 44: "H"},
                },
                22: {
                    "coords": np.array([3.5095, -2.9072, 0.0057]),
                    "element": "C",
                    "bond_to": {10: "C", 33: "C", 45: "H", 46: "H"},
                },
                23: {
                    "coords": np.array([2.2658, -0.1348, 0.3202]),
                    "element": "C",
                    "bond_to": {11: "C", 13: "C", 47: "H"},
                },
                24: {
                    "coords": np.array([-3.0486, 3.753, -0.8571]),
                    "element": "C",
                    "bond_to": {17: "C", 26: "C", 35: "C"},
                },
                25: {
                    "coords": np.array([-4.7892, -1.9053, 0.5602]),
                    "element": "C",
                    "bond_to": {18: "C", 27: "C", 36: "C"},
                },
                26: {
                    "coords": np.array([-4.1304, 2.8451, -0.9341]),
                    "element": "C",
                    "bond_to": {20: "C", 24: "C", 37: "C"},
                },
                27: {
                    "coords": np.array([-3.9471, -2.9601, 0.7181]),
                    "element": "C",
                    "bond_to": {19: "C", 25: "C", 38: "C"},
                },
                28: {
                    "coords": np.array([-0.7823, 3.6329, 0.3107]),
                    "element": "C",
                    "bond_to": {15: "C", 17: "C", 48: "H"},
                },
                29: {
                    "coords": np.array([-1.4551, -3.2035, 0.6248]),
                    "element": "C",
                    "bond_to": {16: "C", 19: "C", 49: "H"},
                },
                30: {
                    "coords": np.array([-4.5176, 0.5263, 0.0526]),
                    "element": "C",
                    "bond_to": {18: "C", 20: "C", 52: "H"},
                },
                31: {
                    "coords": np.array([1.9005, 4.7807, 1.1965]),
                    "element": "C",
                    "bond_to": {12: "C", 53: "H", 54: "H", 55: "H"},
                },
                32: {
                    "coords": np.array([4.8520e00, 2.5394e00, 3.3000e-03]),
                    "element": "C",
                    "bond_to": {21: "C", 39: "C", 56: "H", 57: "H"},
                },
                33: {
                    "coords": np.array([3.9112, -2.9257, -1.4638]),
                    "element": "C",
                    "bond_to": {22: "C", 40: "C", 58: "H", 59: "H"},
                },
                34: {
                    "coords": np.array([1.0259, -4.9791, 0.1919]),
                    "element": "C",
                    "bond_to": {14: "C", 60: "H", 61: "H", 62: "H"},
                },
                35: {
                    "coords": np.array([-2.9926, 5.1012, -1.4661]),
                    "element": "C",
                    "bond_to": {24: "C", 63: "H", 64: "H", 65: "H"},
                },
                36: {
                    "coords": np.array([-6.2814, -1.8735, 0.6439]),
                    "element": "C",
                    "bond_to": {25: "C", 66: "H", 67: "H", 68: "H"},
                },
                37: {
                    "coords": np.array([-5.36, 3.0491, -1.6044]),
                    "element": "C",
                    "bond_to": {26: "C", 41: "C", 69: "H"},
                },
                38: {
                    "coords": np.array([-4.3596, -4.3097, 1.0073]),
                    "element": "C",
                    "bond_to": {27: "C", 42: "C", 70: "H"},
                },
                39: {
                    "coords": np.array([6.3128, 2.4348, 0.3698]),
                    "element": "C",
                    "bond_to": {1: "O", 3: "O", 32: "C"},
                },
                40: {
                    "coords": np.array([5.3729, -3.2588, -1.6419]),
                    "element": "C",
                    "bond_to": {2: "O", 4: "O", 33: "C"},
                },
                41: {
                    "coords": np.array([-6.1715, 2.1311, -2.1847]),
                    "element": "C",
                    "bond_to": {37: "C", 71: "H", 72: "H"},
                },
                42: {
                    "coords": np.array([-4.6339, -5.2115, 0.0645]),
                    "element": "C",
                    "bond_to": {38: "C", 73: "H", 74: "H"},
                },
                43: {
                    "coords": np.array([4.1938, 1.3129, 1.6711]),
                    "element": "H",
                    "bond_to": {21: "C"},
                },
                44: {
                    "coords": np.array([4.1687, 3.0159, 1.9856]),
                    "element": "H",
                    "bond_to": {21: "C"},
                },
                45: {
                    "coords": np.array([3.7406, -3.8863, 0.4471]),
                    "element": "H",
                    "bond_to": {22: "C"},
                },
                46: {
                    "coords": np.array([4.1341, -2.2066, 0.5729]),
                    "element": "H",
                    "bond_to": {22: "C"},
                },
                47: {
                    "coords": np.array([3.3403, -0.1671, 0.1855]),
                    "element": "H",
                    "bond_to": {23: "C"},
                },
                48: {
                    "coords": np.array([-0.7083, 4.7057, 0.4708]),
                    "element": "H",
                    "bond_to": {28: "C"},
                },
                49: {
                    "coords": np.array([-1.5138, -4.2667, 0.8304]),
                    "element": "H",
                    "bond_to": {29: "C"},
                },
                50: {
                    "coords": np.array([-2.0287, 1.2921, 0.8961]),
                    "element": "H",
                    "bond_to": {5: "N"},
                },
                51: {
                    "coords": np.array([-1.9035, -0.5315, 0.0596]),
                    "element": "H",
                    "bond_to": {6: "N"},
                },
                52: {
                    "coords": np.array([-5.5979, 0.6383, 0.092]),
                    "element": "H",
                    "bond_to": {30: "C"},
                },
                53: {
                    "coords": np.array([1.2897, 5.1008, 2.0471]),
                    "element": "H",
                    "bond_to": {31: "C"},
                },
                54: {
                    "coords": np.array([2.9482, 4.9486, 1.4639]),
                    "element": "H",
                    "bond_to": {31: "C"},
                },
                55: {
                    "coords": np.array([1.6775, 5.4274, 0.3414]),
                    "element": "H",
                    "bond_to": {31: "C"},
                },
                56: {
                    "coords": np.array([4.6712, 3.5474, -0.3875]),
                    "element": "H",
                    "bond_to": {32: "C"},
                },
                57: {
                    "coords": np.array([4.6518, 1.8113, -0.7907]),
                    "element": "H",
                    "bond_to": {32: "C"},
                },
                58: {
                    "coords": np.array([3.3272, -3.6772, -2.0076]),
                    "element": "H",
                    "bond_to": {33: "C"},
                },
                59: {
                    "coords": np.array([3.7327, -1.9441, -1.9173]),
                    "element": "H",
                    "bond_to": {33: "C"},
                },
                60: {
                    "coords": np.array([2.0137, -5.3942, -0.029]),
                    "element": "H",
                    "bond_to": {34: "C"},
                },
                61: {
                    "coords": np.array([0.3499, -5.3061, -0.6044]),
                    "element": "H",
                    "bond_to": {34: "C"},
                },
                62: {
                    "coords": np.array([0.6873, -5.4128, 1.1379]),
                    "element": "H",
                    "bond_to": {34: "C"},
                },
                63: {
                    "coords": np.array([-3.5447, 5.8188, -0.8503]),
                    "element": "H",
                    "bond_to": {35: "C"},
                },
                64: {
                    "coords": np.array([-3.4318, 5.0997, -2.4692]),
                    "element": "H",
                    "bond_to": {35: "C"},
                },
                65: {
                    "coords": np.array([-1.9644, 5.4627, -1.568]),
                    "element": "H",
                    "bond_to": {35: "C"},
                },
                66: {
                    "coords": np.array([-6.7151, -1.5506, -0.3082]),
                    "element": "H",
                    "bond_to": {36: "C"},
                },
                67: {
                    "coords": np.array([-6.61, -1.1876, 1.4317]),
                    "element": "H",
                    "bond_to": {36: "C"},
                },
                68: {
                    "coords": np.array([-6.7014, -2.8571, 0.8758]),
                    "element": "H",
                    "bond_to": {36: "C"},
                },
                69: {
                    "coords": np.array([-5.693, 4.0826, -1.6921]),
                    "element": "H",
                    "bond_to": {37: "C"},
                },
                70: {
                    "coords": np.array([-4.4411, -4.5822, 2.0553]),
                    "element": "H",
                    "bond_to": {38: "C"},
                },
                71: {
                    "coords": np.array([-7.0854, 2.4544, -2.6733]),
                    "element": "H",
                    "bond_to": {41: "C"},
                },
                72: {
                    "coords": np.array([-5.9398, 1.0737, -2.2183]),
                    "element": "H",
                    "bond_to": {41: "C"},
                },
                73: {
                    "coords": np.array([-4.9394, -6.2155, 0.3391]),
                    "element": "H",
                    "bond_to": {42: "C"},
                },
                74: {
                    "coords": np.array([-4.5621, -4.9765, -0.9923]),
                    "element": "H",
                    "bond_to": {42: "C"},
                },
                75: {
                    "coords": np.array([8.0834, 2.6451, -0.4143]),
                    "element": "H",
                    "bond_to": {1: "O"},
                },
                76: {
                    "coords": np.array([6.7157, -3.456, -3.0389]),
                    "element": "H",
                    "bond_to": {2: "O"},
                },
            },
            {
                1: {
                    "to_atom_index": 1,
                    "from_atom_index": 39,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                2: {
                    "to_atom_index": 1,
                    "from_atom_index": 75,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                3: {
                    "to_atom_index": 2,
                    "from_atom_index": 40,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                4: {
                    "to_atom_index": 2,
                    "from_atom_index": 76,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                5: {
                    "to_atom_index": 3,
                    "from_atom_index": 39,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                6: {
                    "to_atom_index": 4,
                    "from_atom_index": 40,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                7: {
                    "to_atom_index": 5,
                    "from_atom_index": 17,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                8: {
                    "to_atom_index": 5,
                    "from_atom_index": 20,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                9: {
                    "to_atom_index": 5,
                    "from_atom_index": 50,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                10: {
                    "to_atom_index": 6,
                    "from_atom_index": 18,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                11: {
                    "to_atom_index": 6,
                    "from_atom_index": 19,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                12: {
                    "to_atom_index": 6,
                    "from_atom_index": 51,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                13: {
                    "to_atom_index": 7,
                    "from_atom_index": 11,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                14: {
                    "to_atom_index": 7,
                    "from_atom_index": 15,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                15: {
                    "to_atom_index": 8,
                    "from_atom_index": 13,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                16: {
                    "to_atom_index": 8,
                    "from_atom_index": 16,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                17: {
                    "to_atom_index": 9,
                    "from_atom_index": 11,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                18: {
                    "to_atom_index": 9,
                    "from_atom_index": 12,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                19: {
                    "to_atom_index": 9,
                    "from_atom_index": 21,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                20: {
                    "to_atom_index": 10,
                    "from_atom_index": 13,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                21: {
                    "to_atom_index": 10,
                    "from_atom_index": 14,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                22: {
                    "to_atom_index": 10,
                    "from_atom_index": 22,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                23: {
                    "to_atom_index": 11,
                    "from_atom_index": 23,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                24: {
                    "to_atom_index": 12,
                    "from_atom_index": 15,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                25: {
                    "to_atom_index": 12,
                    "from_atom_index": 31,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                26: {
                    "to_atom_index": 13,
                    "from_atom_index": 23,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                27: {
                    "to_atom_index": 14,
                    "from_atom_index": 16,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                28: {
                    "to_atom_index": 14,
                    "from_atom_index": 34,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                29: {
                    "to_atom_index": 15,
                    "from_atom_index": 28,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                30: {
                    "to_atom_index": 16,
                    "from_atom_index": 29,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                31: {
                    "to_atom_index": 17,
                    "from_atom_index": 24,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                32: {
                    "to_atom_index": 17,
                    "from_atom_index": 28,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                33: {
                    "to_atom_index": 18,
                    "from_atom_index": 25,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                34: {
                    "to_atom_index": 18,
                    "from_atom_index": 30,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                35: {
                    "to_atom_index": 19,
                    "from_atom_index": 27,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                36: {
                    "to_atom_index": 19,
                    "from_atom_index": 29,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                37: {
                    "to_atom_index": 20,
                    "from_atom_index": 26,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                38: {
                    "to_atom_index": 20,
                    "from_atom_index": 30,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                39: {
                    "to_atom_index": 21,
                    "from_atom_index": 32,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                40: {
                    "to_atom_index": 21,
                    "from_atom_index": 43,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                41: {
                    "to_atom_index": 21,
                    "from_atom_index": 44,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                42: {
                    "to_atom_index": 22,
                    "from_atom_index": 33,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                43: {
                    "to_atom_index": 22,
                    "from_atom_index": 45,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                44: {
                    "to_atom_index": 22,
                    "from_atom_index": 46,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                45: {
                    "to_atom_index": 23,
                    "from_atom_index": 47,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                46: {
                    "to_atom_index": 24,
                    "from_atom_index": 26,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                47: {
                    "to_atom_index": 24,
                    "from_atom_index": 35,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                48: {
                    "to_atom_index": 25,
                    "from_atom_index": 27,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                49: {
                    "to_atom_index": 25,
                    "from_atom_index": 36,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                50: {
                    "to_atom_index": 26,
                    "from_atom_index": 37,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                51: {
                    "to_atom_index": 27,
                    "from_atom_index": 38,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                52: {
                    "to_atom_index": 28,
                    "from_atom_index": 48,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                53: {
                    "to_atom_index": 29,
                    "from_atom_index": 49,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                54: {
                    "to_atom_index": 30,
                    "from_atom_index": 52,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                55: {
                    "to_atom_index": 31,
                    "from_atom_index": 53,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                56: {
                    "to_atom_index": 31,
                    "from_atom_index": 54,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                57: {
                    "to_atom_index": 31,
                    "from_atom_index": 55,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                58: {
                    "to_atom_index": 32,
                    "from_atom_index": 39,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                59: {
                    "to_atom_index": 32,
                    "from_atom_index": 56,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                60: {
                    "to_atom_index": 32,
                    "from_atom_index": 57,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                61: {
                    "to_atom_index": 33,
                    "from_atom_index": 40,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                62: {
                    "to_atom_index": 33,
                    "from_atom_index": 58,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                63: {
                    "to_atom_index": 33,
                    "from_atom_index": 59,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                64: {
                    "to_atom_index": 34,
                    "from_atom_index": 60,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                65: {
                    "to_atom_index": 34,
                    "from_atom_index": 61,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                66: {
                    "to_atom_index": 34,
                    "from_atom_index": 62,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                67: {
                    "to_atom_index": 35,
                    "from_atom_index": 63,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                68: {
                    "to_atom_index": 35,
                    "from_atom_index": 64,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                69: {
                    "to_atom_index": 35,
                    "from_atom_index": 65,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                70: {
                    "to_atom_index": 36,
                    "from_atom_index": 66,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                71: {
                    "to_atom_index": 36,
                    "from_atom_index": 67,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                72: {
                    "to_atom_index": 36,
                    "from_atom_index": 68,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                73: {
                    "to_atom_index": 37,
                    "from_atom_index": 41,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                74: {
                    "to_atom_index": 37,
                    "from_atom_index": 69,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                75: {
                    "to_atom_index": 38,
                    "from_atom_index": 42,
                    "bond_type": "2",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                76: {
                    "to_atom_index": 38,
                    "from_atom_index": 70,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                77: {
                    "to_atom_index": 41,
                    "from_atom_index": 71,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                78: {
                    "to_atom_index": 41,
                    "from_atom_index": 72,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                79: {
                    "to_atom_index": 42,
                    "from_atom_index": 73,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
                80: {
                    "to_atom_index": 42,
                    "from_atom_index": 74,
                    "bond_type": "1",
                    "stereo": 0,
                    "topology": 0,
                    "reacting_center_status": 0,
                },
            },
        )
